@@ -129,6 +129,38 @@ def iv_decrypt(number, password):
     cipher = IvCipherCore(password)
     return cipher.decrypt(number)
 
+class IvfCipherCore(IvCipherCore):
+
+    def __init__(self, password, int_digits=12, float_digits=4):
+        super().__init__(password)
+        self.int_digits = int_digits
+        self.float_digits = float_digits
+        self.module = 10 ** (float_digits * 2)
+        self.max_value_length = float_digits * 2 + self.int_digits + 2
+        self.max = 10 ** self.max_value_length - 1
+        self.value_template = "{:0%dd}" % self.max_value_length
+
+    def encrypt(self, number, **kwargs):
+        number = int(number * self.module)
+        number = super().encrypt(number)
+        if number >= 0:
+            return "+" + self.value_template.format(number)
+        else:
+            return "*" + self.value_template.format(self.max - abs(number))
+
+    def decrypt(self, number, **kwargs):
+        sign = number[0]
+        number = int(number[1:])
+        if sign == "*":
+            number = self.max - number
+        number = super().decrypt(number)
+        number = round(number / self.module, self.float_digits)
+        if self.float_digits == 0:
+            number = int(number)
+        if sign == "*":
+            return -1 * number
+        else:
+            return number
 
 class EncoderBase(object):
 
@@ -262,3 +294,14 @@ class IvCipher(CipherBase):
         "encoder": RawDataEncoder(),
         "cipher_core": IvCipherCore,
     }
+
+class IvfCipher(CipherBase):
+
+    defaults = {
+        "encoder": RawDataEncoder(),
+        "cipher_core": IvfCipherCore,
+        "kwargs": {
+            "int_digits": 12,
+            "float_digits": 4,
+        }
+    }
